componenttools.is_immediate_temporal_successor_of_component
===========================================================

.. autofunction:: abjad.tools.componenttools.is_immediate_temporal_successor_of_component.is_immediate_temporal_successor_of_component
   :noindex:
